@@ -1,4 +1,4 @@
-from .bot import Bot
+from .bot import *
 from .api import *
 from .models import *
 from .utils import *
\ No newline at end of file
