@@ -1,3 +1 @@
-"""Utility related modules for selfcord
-"""
 from .command import Command, CommandCollection, Context, ExtensionCollection, Extension, Extender, Event
